@@ -4,23 +4,21 @@ package Crypt::Perl::X;
 
 =head1 NAME
 
-Net::ACME::X - Exception objects for Crypt::Perl
+Crypt::Perl::X - Exception objects for Crypt::Perl
 
 =cut
 
 use strict;
 use warnings;
 
-use File::Spec ();
+use Module::Load ();
 
 sub create {
     my ( $type, @args ) = @_;
 
     my $x_package = "Crypt::Perl::X::$type";
 
-    my $x_pkg_path = File::Spec->catfile( split m<::>, $x_package ) . '.pm';
-
-    require $x_pkg_path;
+    Module::Load::load($x_package);
 
     return $x_package->new(@args);
 }
